@@ -44,7 +44,5 @@ def del_chat(chat_id: int):
     :param chat_id: int
     :return: 200 | 404 | 500
     """
-    r = requests.delete(f"{BASE_URL}/chats/", json={
-        "chat_id": chat_id
-    })
+    r = requests.delete(f"{BASE_URL}/chats/{chat_id}")
     return r.status_code
